[−][src]Struct text_style::termion::TermionStr
A styled string that can be rendered using termion.
The [Display][] implementation of this struct produces a formatted string using the escape
sequencens generated by termion.
Example
use text_style::termion::Termion; println!("{}", text_style::StyledStr::plain("test").bold().termion());